/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import org.apache.tools.ant.Location;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.Target;


/**
 * <p>
 * This class stores some information about an ant task. The ServerAppTestTask uses this class to encapsulate the
 * information, then passes it to the Server implementation through the ServerElement. The information is required to
 * create a Task using the DefaultAntTaskFactory.
 * </p>
 *
 * <p>
 * This class is immutable, so it is thread-safe.
 * </p>
 *
 * @author real_vg, TCSDEVELOPER
 * @version 1.0
 */
public class AntTaskInfo {
    /**
     * <p>
     * Represents the project to which the ant task belongs. Initialized in constructor and then never changed. Cannot
     * be null.
     * </p>
     */
    private final Project project;

    /**
     * <p>
     * Represents the name of the ant task used in logging messages. Initialized in constructor and then never changed.
     * Cannot be null or empty string.
     * </p>
     */
    private final String taskName;

    /**
     * <p>
     * Represents the location where the ant task was defined. Initialized in constructor and then never changed.
     * Cannot be null.
     * </p>
     */
    private final Location location;

    /**
     * <p>
     * Represents the container target of the ant task. Initialized in constructor and then never changed. Cannot be
     * null.
     * </p>
     */
    private final Target target;

    /**
     * <p>
     * Creates a new instance of this class with the specified attributes.
     * </p>
     *
     * @param project the project to which the ant task belongs.
     * @param taskName the name of the ant task used in logging messages.
     * @param location the location where the ant task was defined.
     * @param target the container target of the ant task.
     *
     * @throws IllegalArgumentException if any argument is null; or taskName is empty string.
     */
    public AntTaskInfo(Project project, String taskName, Location location, Target target) {
        if (project == null) {
            throw new IllegalArgumentException("project is null");
        }
        if (taskName == null) {
            throw new IllegalArgumentException("taskName is null");
        }
        if (taskName.trim().length() == 0) {
            throw new IllegalArgumentException("taskName is empty string");
        }
        if (location == null) {
            throw new IllegalArgumentException("location is null");
        }
        if (target == null) {
            throw new IllegalArgumentException("target is null");
        }

        this.project = project;
        this.taskName = taskName;
        this.location = location;
        this.target = target;
    }

    /**
     * <p>
     * Returns the project to which the ant task belongs.
     * </p>
     *
     * @return the project to which the ant task belongs.
     */
    public Project getProject() {
        return project;
    }

    /**
     * <p>
     * Returns the name of the ant task used in logging messages.
     * </p>
     *
     * @return the name of the ant task used in logging messages.
     */
    public String getTaskName() {
        return taskName;
    }

    /**
     * <p>
     * Returns the location where the ant task was defined.
     * </p>
     *
     * @return the location where the ant task was defined.
     */
    public Location getLocation() {
        return location;
    }

    /**
     * <p>
     * Returns the container target of the ant task.
     * </p>
     *
     * @return the container target of the ant task.
     */
    public Target getTarget() {
        return target;
    }
}
