/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework.web;

import org.apache.cactus.JspTestCase;

import javax.servlet.ServletConfig;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import javax.servlet.jsp.JspWriter;
import javax.servlet.jsp.PageContext;


/**
 * <p>
 * This class represents the test case to unit test Custom Tags under the Testing Framework. Test classes that need
 * access to valid JSP API implicit objects must subclass this class. These implicit objects include: the HTTP
 * request, the HTTP response, the servlet config, the session, the JSP writer, the JSP page context. They should be
 * accessed by the corresponding getter methods.
 * </p>
 *
 * <p>
 * As in JUnit, you can define a setUp() and a tearDown() methods. They are executed respectively before and after each
 * test case. However they are executed on the server side. It means that you will be able to access the implicit
 * objects on the server only. The main method for a test is the testXXX() method which are executed in the server
 * container.
 * </p>
 *
 * <p>
 * For each XXX test case, you can define a corresponding beginXXX() method (optional). You will use it to initialize
 * HTTP related parameters (HTTP parameters, cookies, HTTP headers, URL to simulate, ...). Similarly, you can define a
 * corresponding endXXX() method (optional). You will use this method to verify the returned HTTP related parameters
 * from your test case (like the returned content of the HTTP response, any returned cookies, returned HTTP headers,
 * ...). The signatures of these methods are as follows:
 * <pre>
 * public void beginXXX(WebRequest theRequest) {
 *     [...]
 * }
 *  public void endXXX(WebResponse theResponse) {
 *     [...]
 * }
 * </pre>
 * where theRequest is the object that you use to set all the HTTP related parameters, theResponse is the object that
 * you use to verify the returned HTTP related parameters from your test case.
 * </p>
 *
 * <p>
 * No argument check is made in the constructor since it will be called by the JUnit framework. The passed argument
 * should always be valid.
 * </p>
 *
 * @author real_vg, TCSDEVELOPER
 * @version 1.0
 */
public class TCJspTestCase extends JspTestCase {
    /**
     * <p>
     * Default constructor.
     * </p>
     */
    public TCJspTestCase() {
        super();
    }

    /**
     * <p>
     * Constructor with the name of the test case.
     * </p>
     *
     * @param name the name of the test case.
     */
    public TCJspTestCase(String name) {
        super(name);
    }

    /**
     * <p>
     * Returns the config implicit object that will contain all initialization parameters defined in web.xml under the
     * JSP Redirector page definition.
     * </p>
     *
     * @return the config implicit object.
     */
    public ServletConfig getConfig() {
        return config;
    }

    /**
     * <p>
     * Returns the request implicit object that contains the HTTP related parameters set up in the beginXXX() method.
     * </p>
     *
     * @return the request implicit object.
     */
    public HttpServletRequest getRequest() {
        return request;
    }

    /**
     * <p>
     * Returns the response implicit object that contains the HTTP related parameters passed to the endXXX() method.
     * </p>
     *
     * @return the response implicit object.
     */
    public HttpServletResponse getResponse() {
        return response;
    }

    /**
     * <p>
     * Returns the session implicit object that represents the HTTP session for the test case.
     * </p>
     *
     * <p>
     * By default, an HTTP session is always created for your test case. This can be disabled by calling
     * WebRequest.setAutomaticSession(false) method (it is true by default).
     * </p>
     *
     * @return the session implicit object.
     */
    public HttpSession getSession() {
        return session;
    }

    /**
     * <p>
     * Returns the implicit out object that writes data to the response, thereby simulating the body of a tag (if the
     * tag does not modify its body). If the tag does modify its body, then you will need to generate a BodyContent
     * object before writing out the simualted body.
     * </p>
     *
     * @return the implicit out object.
     */
    public JspWriter getOut() {
        return out;
    }

    /**
     * <p>
     * Returns the implicit pageContext object that provides information about the enclosing JSP, such as attributes
     * and body content. It also has methods to access the implicit objects returned by other methods in this class.
     * </p>
     *
     * @return the implicit pageContext object.
     */
    public PageContext getPageContext() {
        return pageContext;
    }
}
